window.onload = function () {
			
    // Customize file menu
    var fileMenuPanelCommand = GC.Spread.Sheets.Designer.getCommand(GC.Spread.Sheets.Designer.CommandNames.FileMenuPanel);
    var oldExecuteFn = fileMenuPanelCommand.execute;
    fileMenuPanelCommand.execute = function (context, propertyName, newValue) {
        oldExecuteFn.apply(this, arguments);
        switch (propertyName) {
            case 'custom_item_print':
                var workbook = context.getWorkbook();
                workbook.print();
                break;
            case 'custom_item_action_1':
                alert('do something for action 1')
                break;
            case 'custom_item_action_2':
                alert('do something for action 2')
                break;
        }
    }

    // Edit existing drop down
    var fontFamilyCmd = GC.Spread.Sheets.Designer.getCommand("fontFamily");
    var customFont = [
        { value: "Test", text: "Test" }
    ];
    fontFamilyCmd.dropdownList = customFont.concat(fontFamilyCmd.dropdownList);
    var index = fontFamilyCmd.dropdownList.map((item) => item.text).indexOf("Arial");
    if (index > -1) {
        fontFamilyCmd.dropdownList.splice(index, 1);
    }

    // Edit existing dialog
    var formatCellsTemplate = GC.Spread.Sheets.Designer.getTemplate("formatDialogTemplate");
    formatCellsTemplate.title = "Custom";
    formatCellsTemplate.content[0].children[4].children[0].children[0].type ='ColorPicker';
    formatCellsTemplate.content[0].children[4].children[0].children[0].bindingPath = 'fillTabOption.backColor';
    GC.Spread.Sheets.Designer.registerTemplate("formatDialogTemplate", formatCellsTemplate);
    
    var config = GC.Spread.Sheets.Designer.DefaultConfig;

    // Add a tab
    config.ribbon.push({
        "id" : "contactUs",
        "text": "Contact Us",
        "buttonGroups": [
            {
                "label": "Contact sales at (+1) 412-681-4343 or us.sales@grapecity.com to request temporary deployment authorization.",
                 "commandGroup": {}    
            }   
        ]
    });

    // Add new context menu items
    config.contextMenu.push(
        "showAlert",
        "insertSignatureTemplate"
    );

    // Add new button
    config.ribbon[0].buttonGroups.splice(1, 0, {
        "label": "ShowTemplate",
        "thumbnailClass": "welcome",
        "commandGroup": {
            "children": [
                {
                    "direction": "vertical",
                    "commands": [
                        "enableDisableTemplate"
                    ]
                }
            ]
        }
    });		

    // Add configuration changes
    config.commandMap = {
        // Disable items in a dialog
        enableDisableTemplate: {
            title: "Show Template",
            text: "Show Template",
            bigButton: false,
            commandName: "showTemplate",
            execute: (context, propertyName) => {
                var dialogOption = {
                    selectType: "range"
                };
                GC.Spread.Sheets.Designer.showDialog("enableDisableTemplate", dialogOption, (result) => {
                }, (error) => {
                    console.error(error);
                });
            }
        },
        fileMenuPanel: fileMenuPanelCommand,
        fontFamily: fontFamilyCmd,
        // Custom dialog
        insertSignatureTemplate: {
            title: "Insert Signature",
            text: "Insert Signature",
            commandName: "insertSignatureTemplate",
            visibleContext: "ClickRowHeader",
            execute: () => {
                // Same template name defined in the JS file
                GC.Spread.Sheets.Designer.showDialog("insertSignatureTemplate");
            }
        },
        // Custom context menu item
        showAlert: {
            text: "Show alert",
            commandName: "showAlert",
            visibleContext: "ClickColHeader",
            execute: () => {
                alert("You clicked the custom context menu item!");
            }
        },			
        // Custom button functionality
        welcome: {
            title: "Welcome",
            text: "Welcome",
            iconClass: "ribbon-button-welcome",
            bigButton: "true",
            commandName: "Welcome",
            execute: async (context, propertyName, fontItalicChecked) => {
                alert('Welcome to the new designer.');
            }
        }
    }

    // Add a new side panel
    config.sidePanels.push(sidePanelsPictureConfig);
    Object.assign(config.commandMap, sidePanelsPictureCommands);

    // Add new button to a tab
    config.ribbon[0].buttonGroups.unshift({
        "label": "NewDesigner",
        "thumbnailClass": "welcome",
        "commandGroup": {
            "children": [
                {
                    "direction": "vertical",
                    "commands": [
                        "welcome"
                    ]
                }
            ]
        }
    });

    var designer = new GC.Spread.Sheets.Designer.Designer(document.getElementById("designerHost"), config);

    // Customize status bar
    var statusBar = GC.Spread.Sheets.StatusBar.findControl(document.getElementsByClassName("gc-statusBar"));
    var spanItem = new GC.Spread.Sheets.StatusBar.StatusItem('spanItem', {menuContent: 'Show Contact', value: 'Contact: us.sales@grapecity.com'});
    statusBar.add(spanItem);

    spread = designer.getWorkbook();
    sheet = spread.getActiveSheet();
    sheet.pictures.add('pic1', 'https://www.grapecity.com/spreadjs/demos/spread/source/logo-en.ico', 30, 30, 200, 40);
}